(setq startup/gc-cons-threshold gc-cons-threshold)
(setq gc-cons-threshold most-positive-fixnum)
(defun startup/reset-gc () (setq gc-cons-threshold startup/gc-cons-threshold))
(add-hook 'emacs-startup-hook 'startup/reset-gc)

(require 'package)

(setq package-archives '(("org"       . "http://orgmode.org/elpa/")
                         ("gnu"       . "http://elpa.gnu.org/packages/")
                         ("melpa"     . "http://melpa.org/packages/")))

(package-initialize)

(unless (package-installed-p 'use-package)
  (package-refresh-contents)
  (package-install 'use-package))

(require 'use-package)

(setq browse-url-browser-function 'browse-url-generic
      browse-url-generic-program "nyxt")

(use-package async
  :ensure t
  :init (dired-async-mode 1))

(use-package exwm
  :ensure t
  :config

    ;; necessary to configure exwm manually
    (require 'exwm-config)

    ;; fringe size, most people prefer 1 
    (fringe-mode 1)

    ;; emacs as a daemon, use "emacsclient <filename>" to seamlessly edit files from the terminal directly in the exwm instance
    (server-start)

    ;; a number between 1 and 9, exwm creates workspaces dynamically so I like starting out with 1
    (setq exwm-workspace-number 1)

    ;; this is a way to declare truly global/always working keybindings
    ;; this is a nifty way to go back from char mode to line mode without using the mouse
    (exwm-input-set-key (kbd "s-r") #'exwm-reset)
    (exwm-input-set-key (kbd "s-k") #'exwm-workspace-delete)
    (exwm-input-set-key (kbd "s-w") #'exwm-workspace-swap)

    ;; the simplest launcher, I keep it in only if dmenu eventually stopped working or something
    (exwm-input-set-key (kbd "s-&")
                        (lambda (command)
                          (interactive (list (read-shell-command "$ ")))
                          (start-process-shell-command command nil command)))

    ;; this just enables exwm, it started automatically once everything is ready
    (exwm-enable))

(menu-bar-mode -1)
(tool-bar-mode -1)
(fringe-mode -1)
(scroll-bar-mode -1)

(setq initial-scratch-message "")

(setq locale-coding-system 'utf-8)
(set-terminal-coding-system 'utf-8)
(set-keyboard-coding-system 'utf-8)
(set-selection-coding-system 'utf-8)
(prefer-coding-system 'utf-8)

;;highlight current line
(global-hl-line-mode +1)

;; show line numbers only on code files
(add-hook 'prog-mode-hook #'display-line-numbers-mode)

(fset 'yes-or-no-p 'y-or-n-p)

(use-package gruvbox-theme
  :ensure t
  :init
   (load-theme 'gruvbox-dark-hard t))

;; set default font
(set-face-attribute 'default nil :font "DejaVu Sans Mono-8")

;; format
(setq display-time-24hr-format t)
(setq display-time-format "%H:%M - %d %B %Y")
;; enable clock
(display-time-mode 1)

(custom-set-faces
 ;; custom-set-faces was added by Custom.
 ;; If you edit it by hand, you could mess it up, so be careful.
 ;; Your init file should contain only one such instance.
 ;; If there is more than one, they won't work right.
 '(elfeed-search-date-face ((t (:inherit font-lock-builtin-face :foreground "#d3869b" :underline nil))))
 '(elfeed-search-feed-face ((t (:foreground "#fabd2f"))))
 '(elfeed-search-filter-face ((t (:inherit mode-line-buffer-id :weight normal))))
 '(elfeed-search-last-update-face ((t (:inherit font-lock-comment-face :foreground "#fdf4c1"))))
 '(elfeed-search-tag-face ((t (:foreground "#83a598"))))
 '(elfeed-search-title-face ((t (:foreground "#fdf4c1"))))
 '(elfeed-search-unread-count-face ((t (:inherit font-lock-comment-face :foreground "#fdf4c1"))))
 '(elfeed-search-unread-title-face ((t nil)))
 '(mentor-download-message ((t (:foreground "#e27878"))))
 '(mentor-download-name ((t (:foreground "#83a598"))))
 '(mentor-download-size ((t (:foreground "#fabd2f"))))
 '(mentor-tracker-name ((t (:foreground "#b8bb26"))))
 '(mingus-album-face ((t (:foreground "#fb4933" :underline t))))
 '(mingus-album-stale-face ((t (:foreground "#fb4933"))))
 '(mingus-artist-face ((t (:foreground "#d3869b"))))
 '(mingus-mark-face ((t (:foreground "#e2a478" :weight bold))))
 '(mingus-song-file-face ((t (:foreground "#8ec07c"))))
 '(mingus-stopped-face ((t (:foreground "#e27878")))))

(defun split-and-follow-horizontally ()
  (interactive)
  (split-window-below)
  (balance-windows)
  (other-window 1))
(global-set-key (kbd "C-x 2") 'split-and-follow-horizontally)

(defun split-and-follow-vertically ()
  (interactive)
  (split-window-right)
  (balance-windows)
  (other-window 1))
(global-set-key (kbd "C-x 3") 'split-and-follow-vertically)

(defun config-visit ()
  (interactive)
  (find-file "~/website/posts/config.org"))
(global-set-key (kbd "C-c e") 'config-visit)

(defun config-reload ()
  "Reloads ~/.emacs.d/config.org at runtime"
  (interactive)
  (org-babel-load-file (expand-file-name "~/.emacs.d/init.el")))
(global-set-key (kbd "C-c r") 'config-reload)

(require 'exwm)
(require 'exwm-config)
(exwm-config-default)

(use-package powerline
  :ensure t
  :init
    (powerline-default-theme))

;; Media layout
(defun lmedia ()
(interactive)
 (dired "~/")
(split-window-below)
(mingus)
(mingus-cancel-timer) ;; stops mingus default behaviour of redisplaying every second, which caused xwindows to flicker and lose focus
(mingus-header-mode)
(split-window-right)
(elfeed)
(other-window 2)
(split-window-right)
(dired "~/"))

;; Social layout
(defun lsocial ()
(interactive)
(mu4e)
(split-window-right)
(erc)
)
;; Web/blog authoring layout to be added

(defun eshell-new()
  "Open a new instance of eshell."
  (interactive)
  (eshell 'N))

(exwm-input-set-key (kbd "<s-return>") #'eshell-new)
; the code below allowes setting urxvt as terminal
; (exwm-input-set-key (kbd "<s-return>")  
;                    (lambda ()  
;                     (interactive)  
;                    (start-process-shell-command "urxvt" nil "urxvt")))

(exwm-input-set-key (kbd "s-l")  
                    (lambda ()  
                      (interactive)  
                      (start-process-shell-command "slock" nil "slock")))

(defun take-screenshot ()
  "Takes a fullscreen screenshot of the current workspace"
  (interactive)
  (when window-system
  (loop for i downfrom 3 to 1 do
        (progn
          (message (concat (number-to-string i) "..."))
          (sit-for 1)))
  (message "Cheese!")
  (sit-for 1)
  (start-process "screenshot" nil "import" "-window" "root" 
             (concat (getenv "HOME") "/" (subseq (number-to-string (float-time)) 0 10) ".png"))
  (message "Screenshot taken!")))
(exwm-input-set-key (kbd "s-P") 'take-screenshot)

(defun close-all-buffers ()
  "Kill all buffers without regard for their origin."
  (interactive)
  (mapc 'kill-buffer (buffer-list)))
(global-set-key (kbd "C-M-s-k") 'close-all-buffers)

(defvar window-split-saved-config nil)

(defun window-split-toggle-one-window ()
  "Make the current window fill the frame.
If there is only one window try reverting to the most recently saved
window configuration."
  (interactive)
  (if (and window-split-saved-config (not (window-parent)))
      (set-window-configuration window-split-saved-config)
    (setq window-split-saved-config (current-window-configuration))
    (delete-other-windows)))

(global-set-key (kbd "C-x 1") 'window-split-toggle-one-window)

(require 'capture)

(setq capture-video-dest-dir "~/screencasts/SORT/")
(global-set-key (kbd "s-c") 'capture-run-mode)

(defun my-capture-presets ()
  "Make my presets for capturing."
  (interactive)
  (capture-presets-clear)
  (capture-add-preset 454 74 1280 720 15 "webm"
                      ""
                      "1280px (no audio)"))
(my-capture-presets)

(use-package chan
  :load-path "lisp/chan")

;;load dired icons
(add-hook 'dired-mode-hook 'all-the-icons-dired-mode)
;; reduce lag from dired-icons
(setq inhibit-compacting-font-caches t)

(defun mydired-sort ()
  "Sort dired listings with directories first."
  (save-excursion
    (let (buffer-read-only)
      (forward-line 2) ;; beyond dir. header 
      (sort-regexp-fields t "^.*$" "[ ]*." (point) (point-max)))
    (set-buffer-modified-p nil)))

(defadvice dired-readin
  (after dired-after-updating-hook first () activate)
  "Sort dired listings with directories first before adding marks."
  (mydired-sort))

(setq-default dired-listing-switches "-alh")

;; load the packaged named xyz.
(load "openwith") ;; best not to include the ending “.el” or “.elc”

(setq large-file-warning-threshold nil)
(require 'openwith)
(openwith-mode t)
(setq openwith-associations '(
			      ("\\.3gp\\|.aac\\|.avi\\||.flac\\|.flv\\|.m4a\\|.m4b\\|.m4v\\|.mkv\\|.mp4\\|.mov\\|.mpg\\|.ogg\\|.ogm\\|.wav\\|.webm\\|.wmv\\'" "mpv" (file))
			      ;;("\\.png\\|.jp?g\\|.gif\\|.webp\\'" "viewnior" (file))
			      ("\\.exe\\'" "wine" (file))
			      ))
;; set epub files to open in nov.el
(add-to-list 'auto-mode-alist '("\\.epub\\'" . nov-mode))

(add-to-list 'auto-mode-alist '("\\.\\(cbr\\)\\'" . archive-mode))

(use-package image
  :defer t
  :init
  (add-hook 'image-mode-hook 'image-transform-fit-to-height)
  (setq image-toggle-animation t)
  (setq image-animate-loop t))

(defun image-delete (confirm) 
  (interactive
     (list (y-or-n-p (format "Delete %s?" buffer-file-name))))
  (when confirm (delete-file (buffer-file-name))))

;; (define-key image-mode-map (kbd "D") 'image-delete)

(add-hook 'dired-load-hook '(lambda () (require 'dired-x))) ; Load Dired X when Dired is loaded.
(setq dired-omit-mode t) ; Turn on Omit mode.

(require 'dired-x)
(setq-default dired-omit-files-p t) ; Buffer-local variable
(setq dired-omit-files (concat dired-omit-files "\\|^\\..+$"))

;; keybinding toggle
(define-key dired-mode-map (kbd "s-h") 'dired-omit-mode)

(use-package dmenu
 :ensure t
 :bind
 ("s-d" . 'dmenu))

(global-set-key (kbd "C-x w") 'elfeed)

;; Load elfeed-org
(require 'elfeed-org)

;; Initialize elfeed-org
(elfeed-org)

;; Optionally specify a number of files containing elfeed
;; configuration. If not set then the location below is used.
(setq rmh-elfeed-org-files (list "~/website/posts/elfeed.org"))

;; (defun anon/elfeed-search-print-entry (entry)
;;     "Print ENTRY to anon's buffer without tags"
;;     (let* ((date (elfeed-search-format-date (elfeed-entry-date entry)))
;; 	   (title (or (elfeed-meta entry :title) (elfeed-entry-title entry) ""))
;; 	   (title-faces (elfeed-search--faces (elfeed-entry-tags entry)))
;; 	   (feed (elfeed-entry-feed entry))
;; 	   (feed-title
;; 	(when feed
;; 	  (or (elfeed-meta feed :title) (elfeed-feed-title feed))))
;; 	   (title-width (- (window-width) 10 elfeed-search-trailing-width))
;; 	   (title-column (elfeed-format-column
;; 		  title (elfeed-clamp
;; 		     elfeed-search-title-min-width
;; 		     title-width
;; 		     elfeed-search-title-max-width)
;; 		  :left)))
;;       (insert (propertize date 'face 'elfeed-search-date-face) " ")
;;       (insert (propertize title-column 'face title-faces 'kbd-help title) " ")
;;       (when feed-title
;; 	(insert (propertize feed-title 'face 'elfeed-search-feed-face) " "))))

;; (setq elfeed-search-print-entry-function #'anon/elfeed-search-print-entry)

(setq-default elfeed-search-filter "@5-days-ago +videos")

(defun elfeed-play-with-mpv ()
  "Play entry link with mpv."
  (interactive)
  (let ((entry (if (eq major-mode 'elfeed-show-mode) elfeed-show-entry (elfeed-search-selected :single)))
        (quality-arg "")
        )
    (message "Opening %s with mpv..." (elfeed-entry-link entry))
    (start-process "elfeed-mpv" nil "mpv" (elfeed-entry-link entry))))

(defvar elfeed-mpv-patterns
  '("youtu\\.?be")
  "List of regexp to match against elfeed entry link to know
whether to use mpv to visit the link.")

(eval-after-load 'elfeed-search
 '(define-key elfeed-search-mode-map (kbd "o") 'elfeed-play-with-mpv))

;; Set executable path
 (setq youtube-dl-path "/usr/bin/youtube-dl")
 ;; Set video storage path
 (setq youtube-dl-output-dir "~/Downloads/youtube-dl/")

(defun elfeed-download-video (entry)
  "Download a video using youtube-dl."
  (interactive (list (elfeed-search-selected :ignore-region)))
  (async-shell-command (format "%s -o \"%s%s\" -f bestvideo+bestaudio %s"
                               youtube-dl-path
                               youtube-dl-output-dir
                               "%(title)s.%(ext)s"
                               (elfeed-entry-link entry))))

 ;; set keybinding
 (eval-after-load 'elfeed-search
  '(define-key elfeed-search-mode-map (kbd "d") 'elfeed-download-video))

(setq-default elfeed-initial-tags nil)
(setq-default elfeed-search-date-format (quote ("%a, %R" 10 :left)))
(setq-default elfeed-curl-max-connections 100)
(setq-default elfeed-search-trailing-width 30)

(require 'engine-mode)
(engine-mode t)

(defengine amazon
  "https://www.amazon.co.uk/s?k=%s"
  :keybinding "a")

(defengine bitchute
  "https://www.bitchute.com/search/?query=%s"
  :keybinding "b")

(defengine duckduckgo
  "https://duckduckgo.com/?q=%s"
  :keybinding "d")

(defengine ebay
  "https://www.ebay.co.uk/sch/i.html?_nkw=%s"
  :keybinding "e")

(defengine github
  "https://github.com/search?ref=simplesearch&q=%s")

(defengine google
  "http://www.google.com/search?ie=utf-8&oe=utf-8&q=%s"
  :keybinding "g")

(defengine google-images
  "https://www.google.co.uk/search?tbm=isch&q=%s"
  :keybinding "i")

(defengine google-maps
  "http://maps.google.com/maps?q=%s"
  :docstring "Mappin' it up.")

(defengine odyseee
  "https://odysee.com/$/search?q=%s"
  :keybinding "o")

(defengine peertube
  "https://search.joinpeertube.org/search?search=%s"
  :keybinding "p")

(defengine project-gutenberg
  "http://www.gutenberg.org/ebooks/search/?query=%s")

(defengine qwant
  "https://www.qwant.com/?q=%s")

(defengine rfcs
  "http://pretty-rfc.herokuapp.com/search?q=%s")

(defengine stack-overflow
  "https://stackoverflow.com/search?q=%s")

(defengine startpage
  "https://searx.info/search?q=%s"
  :keybinding "s")

(defengine twitter
  "https://twitter.com/search?q=%s")

(defengine wikipedia
  "http://www.wikipedia.org/search-redirect.php?language=en&go=Go&search=%s"
  :keybinding "w"
  :docstring "Searchin' the wikis.")

(defengine wiktionary
  "https://www.wikipedia.org/search-redirect.php?family=wiktionary&language=en&go=Go&search=%s")

(defengine wolfram-alpha
  "http://www.wolframalpha.com/input/?i=%s")

(defengine youtube
  "http://www.youtube.com/results?aq=f&oq=&search_query=%s"
  :keybinding "y")

(ivy-mode 1)

;  (setq-default mentor-rtorrent-keep-session t)

(use-package mu4e
  :ensure nil
  ;; :load-path "/usr/share/emacs/site-lisp/mu4e/"
  :defer 20 ; Wait until 20 seconds after startup
  :config

  ;; This is set to 't' to avoid mail syncing issues when using mbsync
  (setq mu4e-change-filenames-when-moving t)

  ;; Refresh mail using isync every 10 minutes
  (setq mu4e-update-interval (* 10 60))
  (setq mu4e-get-mail-command "mbsync -a")
  (setq mu4e-maildir "~/Mail")

  ;; Configure the function to use for sending mail
  (setq message-send-mail-function 'smtpmail-send-it)

  (setq mu4e-contexts
	(list
	 ;; Old account
	 (make-mu4e-context
	  :name "Old"
	  :match-func
	  (lambda (msg)
	    (when msg
	      (string-prefix-p "/Gmail" (mu4e-message-field msg :maildir))))
	  :vars '((user-mail-address . "hunt.jonr@gmail.com")
		  (user-full-name    . "Jon Hunts Gmail")
		  (smtpmail-smtp-server . "smtp.gmail.com")
		  (smtpmail-smtp-service . 465)
		  (smtpmail-stream-type . ssl)
		  (mu4e-drafts-folder . "/Gmail/[Gmail]/Drafts")
		  (mu4e-sent-folder . "/Gmail/[Gmail]/Sent Mail")
		  (mu4e-refile-folder . "/Gmail/[Gmail]/All Mail")
		  (mu4e-trash-folder . "/Gmail/[Gmail]/Trash")))

	 ;; Personal account
	 (make-mu4e-context
	  :name "Personal"
	  :match-func
	  (lambda (msg)
	    (when msg
	      (string-prefix-p "/Personal" (mu4e-message-field msg :maildir))))
	  :vars '((user-mail-address . "jon@jonhunt.uk")
		  (user-full-name    . "Jon Hunt")
		  (smtpmail-smtp-server . "mail.jonhunt.uk")
		  (smtpmail-smtp-service . 587)
		  (smtpmail-stream-type . tls)
		  (mu4e-drafts-folder . "/Personal/Drafts")
		  (mu4e-sent-folder . "/Personal/Sent")
		  (mu4e-refile-folder . "/Personal/Archive")
		  (mu4e-trash-folder . "/Personal/Trash")))))


  (setq mu4e-maildir-shortcuts
	'(("/Gmail/Inbox"               . ?i)
	  ("/Gmail/[Gmail]/Sent Mail"   . ?s)
	  ("/Gmail/[Gmail]/Trash"       . ?t)
	  ("/Gmail/[Gmail]/Drafts"      . ?d)
	  ("/Gmail/[Gmail]/All Mail"    . ?a)))

  ;; open with first context by default
  (setq mu4e-context-policy 'pick-first)

  ;; Run mu4e in the background to sync mail periodically
  (mu4e t))

(exwm-input-set-key (kbd "<s-tab>") #'mpd-pause)
(exwm-input-set-key (kbd "s-,") #'mpd-prev)
(exwm-input-set-key (kbd "s-.") #'mpd-next)
(exwm-input-set-key (kbd "s-9") #'mingus-vol-down)
(exwm-input-set-key (kbd "s-0") #'mingus-vol-up)
(exwm-input-set-key (kbd "s-n") #'mingus-seek)
(exwm-input-set-key (kbd "s-p") #'mingus-seek-backward)

(setq-default mingus-mode-always-modeline t)
(setq-default mingus-mode-line-separator " > ")
(setq-default mingus-mode-line-string-max 60)
(setq-default mingus-use-mouse-p nil)

(require 'mingus)
(require 'powerline)

;;;; Customization

(defgroup mingus-header nil
  "Customizations for `mingus-header-mode'."
  :group 'mingus)

(defcustom mingus-header-use-powerline t
  "Use `powerline' to create the header."
  :group 'mingus-header)

;;;; Header Line Creation

(defun mingus-header-line-format ()
  "Create a header line for `mingus-playlist-mode'."
  (if mingus-header-use-powerline
      (mingus-header-powerline-format)
    "not yet implemented"))

;;;;; Powerline version

(defun mingus-header-powerline-format ()
  "Create a header line for `mingus-playlist-mode' using the
`powerline' package."
  (let* ((status (mpd-get-status mpd-inter-conn))
         ;; Whether to show the current song's information.
         (show-song (member (plist-get status 'state) '(play pause)))
         ;; Powerline information.
         (active (powerline-selected-window-active))
         (face1 (if active 'mode-line 'mode-line-inactive))
         (face2 (if active 'powerline-active1 'powerline-inactive1))
         (face3 (if active 'powerline-active2 'powerline-inactive2))
         (face4 (if active 'mode-line-buffer-id 'mode-line-buffer-id-inactive))
         (sep-left (intern (format "powerline-%s-%s"
                                   (powerline-current-separator)
                                   (car powerline-default-separator-dir))))
         (sep-right (intern (format "powerline-%s-%s"
                                    (powerline-current-separator)
                                    (cdr powerline-default-separator-dir))))
         ;; MPD state string.
         (state  (case (plist-get status 'state)
                   (play  "playing ")
                   (pause "paused ")
                   (stop  "stopped ")
                   (t     "error ")))
         ;; Volume string.
         (volume (if (= (plist-get status 'volume) 100) "Vol: 100%% "
                   (format "Vol:  %d%%%% " (plist-get status 'volume))))
         ;; Playback string.
         (single (plist-get status 'single))
         (consume (plist-get status 'consume))
         (playback (format "%s%s%s%s- "
                           (if (eq (plist-get status 'repeat) 1) "r" "-")
                           (if (eq (plist-get status 'random) 1) "z" "-")
                           (if (and single (string= single "1")) "s" "-")
                           (if (and consume (string= consume "1")) "c" "-")))
         ;; Elapsed time string (only when playing/paused).
         (time (if (not show-song) ""
                 (format "%s/%s "
                         (mingus-sec->min:sec (plist-get status 'time-elapsed))
                         (mingus-sec->min:sec (plist-get status 'time-total)))))
         (lhs (list (powerline-raw (propertize state 'face face4) face1 'l)
                    (when show-song
                      (funcall sep-left face1 face2))
                    (when show-song
                      (powerline-raw time face2 'l))
                    (funcall sep-left face2 face3)))
         (rhs (list (funcall sep-right face3 face2)
                    (powerline-raw volume face2 'l)
                    (funcall sep-right face2 face1)
                    (powerline-raw playback face1 'l))))
    (concat (powerline-render lhs)
            (powerline-fill face3 (powerline-width rhs))
            (powerline-render rhs))))

;;;; Minor Mode Definition

(define-minor-mode mingus-header-mode
  "A minor mode for displaying MPD information in the header line
of `mingus-playlist-mode' buffers.
Note that toggling this mode will fail in all other modes."
  :group 'mingus-header
  (if (not (eq major-mode 'mingus-playlist-mode))
      (progn
        ;; Toggling this minor mode only works in `mingus-playlist-mode'.
        (setq mingus-header-mode (not mingus-header-mode))
        (user-error "`mingus-header-mode' can only be enabled in `mingus-playlist-mode' buffers."))
    (if (not mingus-header-mode)
        (setq header-line-format nil)
      (setq header-line-format
            '("%e" (:eval (mingus-header-line-format)))))))

(provide 'mingus-header-mode)

(setq org-hierarchical-todo-statistics nil)

(org-babel-do-load-languages
 'org-babel-load-languages
 '((emacs-lisp . t)
 (python . t)))

(push '("conf-unix" . conf-unix) org-src-lang-modes)

;; stop it asking for confirmation upon evaluating code blocks
(setq org-confirm-babel-evaluate nil)

(require 'org-tempo)

(add-to-list 'org-structure-template-alist '("sh" . "src shell"))
(add-to-list 'org-structure-template-alist '("el" . "src emacs-lisp"))
(add-to-list 'org-structure-template-alist '("py" . "src python"))
(add-to-list 'org-structure-template-alist '("conf" . "src conf"))

;;(pdf-tools-install)

(setq pdf-view-resize-factor 1.1)

(setq-default pdf-view-display-size 'fit-page)

(setq org-static-blog-publish-title "Jon's website")
(setq org-static-blog-publish-url "https://jonhunt.uk/")
(setq org-static-blog-publish-directory "~/website/")
(setq org-static-blog-posts-directory "~/website/posts/")
(setq org-static-blog-drafts-directory "~/website/drafts/")
(setq org-static-blog-use-preview t)
(setq org-static-blog-preview-convert-titles t)
(setq org-static-blog-preview-ellipsis "...")
(setq org-static-blog-enable-tags t)
(setq org-export-with-toc t)
(setq org-export-with-section-numbers nil)
(setq org-src-fontify-natively t
    org-src-tab-acts-natively t
    org-confirm-babel-evaluate nil
    org-edit-src-content-indentation 0)

(setq org-static-blog-page-header
"<meta name=\"author\" content=\"Jon Hunt\">
<meta name=\"referrer\" content=\"no-referrer\">
<meta name=\"referrer\" content=\"no-referrer\">
<meta content=\"width=device-width\" initial-scale=\"1\" name=\"viewport\" />
<link href= \"static/style.css\" rel=\"stylesheet\" type=\"text/css\" />
<link rel=\"icon\" href=\"static/favicon.ico\">")

(setq org-static-blog-page-preamble
"<header>
    <h1>Jonathan Hunt</a></h1>
    <span class=\"subtitle\">―― <a href=\"index\">jonhunt.uk</a> ――</span>
  <nav>
    <ul>
  <li><a href=\"index\">Home</a></li>
  <li><a href=\"https://jonhunt.uk/about-me\">About me</a></li>
  <li><a href=\"https://jonhunt.uk/resources\">Resources</a></li>
  <li><a href=\"https://jonhunt.uk/rss.xml\">RSS</a></li>
  <li><a href=\"https://jonhunt.uk/contact-and-support\">Contact and support</a></li>
</ul>
  </nav>
    </header>
")

(setq org-static-blog-page-postamble
"")

(setq inhibit-startup-screen t)
(delete-other-windows)
(exwm-workspace-switch-create 2)
(lmedia)
(exwm-workspace-switch-create 1)
(start-process-shell-command "nyxt" nil "nyxt")
